function MakePrintable()
%MakePrintable() Plots parameter data in printable window
%   Kevin Mackie, 2001/06/06
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
% Internal function used to print plots to files

% useful values of Axes
% 'Children'
% 'FontName'
% 'FontSize'
% 'FontUnits'
% 'FontAngle'
% 'Position' [left bottom width height]
% 'Tag'
% 'Title'
% 'XLabel' and 'YLabel'
% 'XGrid' and 'YGrid'
% 'XLim', 'YLim', 'ZLim'             [minimum maximum]
% 'XScale', 'YScale', 'ZScale'       {linear}, log

% useful values of Line Children
% 'Color'
% RGB Value Short Name Long Name
%  [1 1 0] y yellow
%  [1 0 1] m magenta 
%  [0 1 1] c cyan
%  [1 0 0] r red
%  [0 1 0] g green
%  [0 0 1] b blue
%  [1 1 1] w white
%  [0 0 0] k black
% 'LineStyle'    {-} | -- | : | -. | none
% 'LineWidth'
% 'Marker'       any of the characters
% 'MarkerEdgeColor'        ColorSpec | none | {auto}
% 'MarkerFaceColor'        ColorSpec | {none} | auto
% 'MarkerSize'
% 'Tag'
% 'XData','YData','ZData'       vector of coordinates

%set( gca, 'NextPlot', 'ReplaceChildren' )
%set(get(gcf,'Parent'),'ShowHiddenHandles','on');

sigpos=[];
twod=1;
H=get(gcf,'Tag');

% check for one of the given windows, or leave generally 
if strcmp(H,'PSDM')
   HA = findobj('Tag','Axes1');     	% axes must be named Axes1 in GUISetup.m
elseif strcmp(H,'Atten')
   HA = findobj('Tag','Axes2');     	% axes must be named Axes2 in AttenGUI.m
else
   HA = gca;
   disp('Warning: Not plotting from PSDM or Atten windows');
end;

plotobjs = get(HA,'Children');
datal=0;
for kr=1:length(plotobjs),
   typer=get(plotobjs(kr),'Type');
   if typer=='line',
      datal=datal+1;
	  data{datal}.x=get(plotobjs(kr),'XData');
	  data{datal}.y=get(plotobjs(kr),'YData');
	  data{datal}.z=get(plotobjs(kr),'ZData');
	  if ~isempty(data{datal}.z),
	     twod=0;
	  end
	  data{datal}.c=get(plotobjs(kr),'Color');
	  data{datal}.l=get(plotobjs(kr),'LineStyle');
	  data{datal}.w=get(plotobjs(kr),'LineWidth');
	  data{datal}.m=get(plotobjs(kr),'Marker');
	  data{datal}.f=get(plotobjs(kr),'MarkerFaceColor');
	  data{datal}.s=get(plotobjs(kr),'MarkerSize');
	  
	  % convert rgb colors to plot commands
	  if data{datal}.c==[1 0 1],
		    color{datal}='m';
      elseif data{datal}.c==[1 1 0],
		    color{datal}='y';
	  elseif data{datal}.c==[0 1 1],
		    color{datal}='c';
	  elseif data{datal}.c==[1 0 0],
		    color{datal}='r';
	  elseif data{datal}.c==[0 1 0],
		    color{datal}='g';
	  elseif data{datal}.c==[0 0 1],
		    color{datal}='b';
	  elseif data{datal}.c==[0 0 0],
		    color{datal}='k';
	  else
		    color{datal}='k';
	  end;
	  
	  % convert plot points to plot commands
	  if strcmp(data{datal}.m,'square')
		    data{datal}.m='s';
	  elseif strcmp(data{datal}.m,'diamond')
		    data{datal}.m='d';
	  elseif strcmp(data{datal}.m,'pentagram')
		    data{datal}.m='p';
	  elseif strcmp(data{datal}.m,'hexagram')
		    data{datal}.m='h';
	  end;
	  
	  if strcmp(data{datal}.m,'none')
         marker{datal}=strcat(color{datal},data{datal}.l);
	  else
	     marker{datal}=strcat(color{datal},data{datal}.m);
	  end;

   elseif typer=='text',    % just has title and axes labels, other text, etc
      if strcmp(get(plotobjs(kr),'Tag'),'sigma')
   	     sigma=get(plotobjs(kr),'String');
		 sigpos=get(plotobjs(kr),'Position');
	  end;
   end;
end;
plottitl = get(get(HA,'Title'),'String');
plotxlab = get(get(HA,'XLabel'),'String');
plotylab = get(get(HA,'YLabel'),'String');
if twod == 0,
   plotzlab = get(get(HA,'ZLabel'),'String');
end;
plotxlim = get(HA,'XLim');
plotylim = get(HA,'YLim');
plottype = get(HA,'XScale');
plotyype = get(HA,'YScale');

% legend properties
LA = get(findobj('Tag','legend'),'Children');
legl=0;
for kr=1:length(LA),
   typer=get(LA(kr),'Type');
   if typer=='text',
      typer=get(LA(kr),'String');
      if isempty(typer)==0,
         legl=legl+1;
	     leg{legl}.t=get(LA(kr),'String');
	  end;
   end;
end;

% backwards compatibility with older Matlab versions and Windows
% Version 6.5 also seems to need this
if legl == 1,
   howm=size(leg{1}.t);
   if howm(1)>1,
      legl=howm(1);
      leg{1}.t=flipud(leg{1}.t);
      for kr=legl:-1:1,
         leg{kr}.t=leg{1}.t(kr,:);
      end;
   end;
end;

newfig = figure('PaperPosition',[1 1 6 4], ...
	'Tag','MakePrintable', ...
	'Name','Printable Plot', ...
	'NumberTitle','off');
newax = axes('Parent',newfig, ...
	'Tag','Axes3');

if twod == 1,
   logplot='HN=loglog(';
elseif twod == 0,
   logplot='HN=plot3(';
end;
legplot='legend(';

for k=datal:-1:1,
   if twod == 1,
      logplot=sprintf('%sdata{%i}.x,data{%i}.y,marker{%i}',logplot,k,k,k);
   elseif twod == 0,
      logplot=sprintf('%sdata{%i}.x,data{%i}.y,data{%i}.z,marker{%i}',logplot,k,k,k,k);
   end;
   
   if k>1,
      logplot=sprintf('%s, ',logplot);
   end;
end
logplot=sprintf('%s);',logplot);
eval(logplot);

title(plottitl);
xlabel(plotxlab);
ylabel(plotylab);
if twod == 0,
   zlabel(plotzlab);
   view(180,0);
   set(gca,'XDir','reverse');
   set(gca,'YScale','log');
   set(gca,'XScale','log');
   set(gca,'ZScale','log');
   axis tight;
end;
set(HN,'MarkerSize',data{1}.s);
set(newax,'XLim',plotxlim);
set(newax,'YLim',plotylim);
set(newax,'XScale',plottype);
set(newax,'YScale',plotyype);
grid;
if twod > 0,
   vax=axis;
   dax=vax/20;
   axis([vax(1)-dax(1) vax(2)+dax(2) vax(3)-dax(3) vax(4)+dax(4)]);
   [vax(1)-dax(1) vax(2)+dax(2) vax(3)-dax(3) vax(4)+dax(4)];
end;

% fix other properties if necessary
newobjs = get(newax,'Children');
for k=legl:-1:1,
   legplot=sprintf('%sleg{%i}.t',legplot,k);
   if k>1,
      legplot=sprintf('%s, ',legplot);
   end;
end
legplot=sprintf('%s,4);',legplot);
if ~isempty(LA),
   eval(legplot);
end;

% add other plot text, if necessary
if ~isempty(sigpos)
   TT=text( sigpos(1),sigpos(2) ,sigma);
   set(TT,'FontSize',9);
   set(TT,'VerticalAlignment','top');
end;

% now print and clean up
prompt='Enter file name:';
titl='Print to File';
def={'Figure1'};
answer=inputdlg(prompt,titl,1,def);
tf=fullfile(matlabroot,answer{1});
figurehand=sprintf('-f%i',newfig);

% version specific file outputs
vtype=version;
if str2num(vtype(1)) == 5,
   eval(['print -depsc2 -tiff ''' tf '.eps'' ' figurehand]);
   %eval(['print -dpsc2 ''' tf '.ps'' ' figurehand]);
   %eval(['print -dmfile ''' tf '.m'' ' figurehand]);
elseif str2num(vtype(1)) == 6,
   eval(['print -depsc2 -tiff ' tf ' ' figurehand]);
   %eval(['print -djpeg99 -r144 ' tf ' ' figurehand]);
   eval(['print -dtiff -r144 ' tf ' ' figurehand]);
else
   disp('Unknown Matlab version number in MakePrintable.m');
end;

% computer specific file outputs
comptype=computer;
if strcmp(comptype,'MAC2')==1,
   eval(['print -dpict -r72 ''' tf '.pic'' ' figurehand]);
end;

close(newfig);

%set(get(gcf,'Parent'),'ShowHiddenHandles','off');
