function PlotAtten()
%PlotAtten(xname,yname) Plots attenuation relationships
%   Kevin Mackie, 2002/07/26
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   INPUT: xname label for x-axis
%		   yname label for y-axis
%
%   Plots any number of overlapping attenuation curves

global XAX;
global YAX;
global NVALS;
global b_in

xname=NVALS(XAX,:);
yname=NVALS(YAX,:);

% b_in (GLOBAL) column vector of regression coefficients
b=b_in;

for k=1:length(b)-2,
   tt=sprintf('EditText%i',k);
   dv(k)=str2num(get(findobj('Tag',tt),'String'));
end;
for k=11:12,
   tt=sprintf('EditText%i',k);
   dv(k)=str2num(get(findobj('Tag',tt),'String'));
end;

% note that dv(1)->dv(10) are possible design parameters
% dv(11) is the IM max extent
% dv(12) is the EDP max extent

HH = findobj('Tag','Axes2');     	% axes must be named Axes2 in GUI
axes(HH);						    % make them current

% eg for 1 bent bridge
% ln(EDP)=A+Bln(IM)+C*LoH+D*DcDs+E*rhos+F*L+G*wt+H*ksoil+I*fy+J*fc+K*rhot+L*skew
ystep=100;
im=0.01:dv(11)/ystep:dv(11);

if length(b) < 12,
   b=[b;zeros(12-length(b),1)];
end;

for k=1:length(im),
   lnedp(k)=b'*[1;log(im(k));dv(1:10)'];
end;
edp=exp(lnedp);
hold on;
loglog(edp,im);
grid on;
hold off;
