function PlotSeismicity(grp,EQ,DATA,xname,yname,fit,addsig)
%PlotSeismicity(grp,DATA,xname,yname,fit) Plots seismicity data
%   Kevin Mackie, 2001/07/18
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   INPUT: grp1->grp4 (Ax2) matrices of data in linear space
%          A corresponds to total number of input files considered
%          1st column is x (DM), 2nd column y (IM) 
%          EQ number of earthquake bins sent in
%          DATA array of information about group and type
%          xname label for x-axis
%          yname label for y-axis
%          fit 1 linear 2 bilinear
%          addsig 1 mean only 2 mean+1 sigma
%
% Interpolation functions are fitting the DM given the IM (ie, y given x)
% but don't be fooled by the "reversed" axis plotting of these measures
% Output linear fits are of form log(DM)=A+B log(IM)
%
% Plots the IM DM relationship showing sensitivity of the relationship
% to groud motion bins.  In this case, 4 bins are LMSR, LMLR, SMSR, SMLR

[m,n]=size(grp);

[xylog,linexlog,lineylog,Fits,Dispersion,ssig]=FitData(grp,fit,EQ);

% output to command line
Fits
Dispersion

HH = findobj('Tag','Axes1');     	% axes must be named Axes1 in GUI
axes(HH);						    % make them current

clrs='brmgcykbrmgcy';
lins='ox+^*sdv<>ph.';

logplot='H=loglog(';
for k=1:n,
   logplot=sprintf('%sxylog{%i}.v(:,1),xylog{%i}.v(:,2),''%c%c'', ', ...
      		logplot,k,k,clrs(k),lins(k));
end
for k=1:n,
   logplot=sprintf('%slinexlog{%i},lineylog{%i},''%c-''',logplot,k,k,clrs(k));
   if k<n,
      logplot=sprintf('%s, ',logplot);
   end;
end

if addsig == 2,
   for k=1:n,
      logplot=sprintf('%s,linexlog{%i},ssig{%i}.p,''%c-.'',linexlog{%i},ssig{%i}.m,''%c-.''', ...
   			logplot,k,k,clrs(k),k,k,clrs(k));
   end
end;

logplot=sprintf('%s);',logplot);

eval(logplot);
axis tight;
set(H,'MarkerSize',4);
grid on;
xlabel(xname);
ylabel(yname);
title('Intensity Measure vs Demand Measure (Seismicity)');
% this needs to be adjusted for non-standard number of bins
% and to reflect IDA EQk's as necessary
legend('LMSR','LMLR','SMSR','SMLR',4);
set(HH,'Tag','Axes1');

vax=axis;

% add sigma info to plot
siginf='\sigma=';
for k=1:n,
   siginf=sprintf('%s%1.2f',siginf,Dispersion(k));
   if k<n,
      siginf=sprintf('%s, ',siginf);
   end;
end;
TT=text( vax(1)+(vax(2)-vax(1))/500, vax(4)-(vax(4)-vax(3))/500 ,siginf);
set(TT,'Tag','sigma');
set(TT,'FontSize',9);
set(TT,'VerticalAlignment','top');
