function PlotVector(grp,EQ,DATA,xname,yname,zname)
%PlotVector(grp,DATA,xname,yname) Plots 3D IM-EDP vectors
%   Kevin Mackie, 2001/07/19
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   INPUT: grp (Ax3) matrices of data in linear space
%          A corresponds to total number of input files considered
%          1st column is x (DM), 2nd column y (IM), 3rd column is M,R, etc
%          make sure correction for SI units is appropriate 
%          EQ number of earthquake bins sent in
%          DATA array of information about group and type
%          xname label for x-axis
%          yname label for y-axis
%          zname label for z-axis
%
% Interpolation functions are fitting the DM given the IM (ie, y given x)
% but don't be fooled by the "reversed" axis plotting of these measures
% Output linear fits are of form log(DM)=A+B log(IM)
%
% Plots the residual of the IM DM relationship (DMfit-DM) versus dependent
% quantities such as Magnitude (M) and Distance (R)

[m,n]=size(grp);

HH = findobj('Tag','Axes1');     	% axes must be named Axes1 in GUI
axes(HH);						    % make them current

clrs='brmgcykbrmgcy';
lins='ox+^*sdv<>ph.';

logplot='H=plot3(';
legplot='legend(';
for k=1:n,
   grp{k}.v=sortrows(grp{k}.v,[1]);
   rat{k}=grp{k}.v(:,2)./grp{k}.v(:,3);
   logplot=sprintf('%sgrp{%i}.v(:,2),rat{%i},grp{%i}.v(:,1),''%c%c''', ...
   				logplot,k,k,k,clrs(k),lins(k));
   legplot=sprintf('%sstrcat(DATA.name,''='',num2str(DATA.vals(%i)))',legplot,k);
   if k<n,
      logplot=sprintf('%s, ',logplot);
	  legplot=sprintf('%s, ',legplot);
   end;
end

logplot=sprintf('%s);',logplot);
legplot=sprintf('%s,4);',legplot);

eval(logplot);
axis tight;
set(H,'MarkerSize',4);
grid on;
%set(gca,'XScale','log');
%set(gca,'ZScale','log');
xlabel(xname);
ylabel(strcat(xname,yname));
zlabel(zname);
title('Vector Intensity Measure - Demand Measure');
eval(legplot);
set(HH,'Tag','Axes1');
