function [xvar,yvar,varargout] = ReadFile(file,identify,xval,yval,varargin)
%ReadFile(file,identify,xval,yval,zval) Provide data from file
%   Kevin Mackie, 2002/05/13
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   INPUT: xval - number of DM in summary file
%          yval - number of IM in summary file
%          zval - number of OPTIONAL IM value(s) for 3D implementation
%          file - total path to file to open and process
%          identify - file name minus all the path information
%
% Extracts data from files which have been pre-processed into .mat files
% using ConvertFiles.m.  Allows for extraction of 3 properties (ie, two DM's, 
% one IM for 3D plots)
%
% values over 200 indicate that the second column of data is desired,
% not that first

xrem=1;yrem=1;zrem=1;zrem2=1;

if nargin<5,
   zval=-1;
   zval2=-1;
elseif nargin<6,
   zval=varargin{1};
   zval2=-1;
else
   zval=varargin{1};
   zval2=varargin{2};
end;

   if (xval > 200),
      xval=xval-200;
      xrem=2;
   end;
   if (yval > 200) 
      yval=yval-200;
      yrem=2;
   end;
   if (zval > 200) 
      zval=zval-200;
      zrem=2;
   end;
   if (zval2 > 200) 
      zval2=zval2-200;
      zrem2=2;
   end;

% variable name used in .mat files is filedata
load(file);
cmd=sprintf('%s=filedata;',identify);
eval(cmd);

cmd=sprintf('xvar=%s(xval,xrem);',identify);
eval(cmd);
cmd=sprintf('yvar=%s(yval,yrem);',identify);
eval(cmd);
if zval>0
   cmd=sprintf('zvar=%s(zval,zrem);',identify);
   eval(cmd);
   varargout{1}=zvar;
end;
if zval2>0
   cmd=sprintf('zvar2=%s(zval2,zrem2);',identify);
   eval(cmd);
   varargout{2}=zvar2;
else 
   varargout{2}=-1;
end;
