function SavePlot()
%SavePlot() Saves data for ida-psdm window comparison
%   Kevin Mackie, 2001/09/14
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
% Call from command line.  Once records the current plot.
% Second call saves comparison plot.  Works better if IDA
% save first, then PSDA (plots with correct extents)

sigpos=[];
twod=1;
HA = findobj('Tag','Axes1');     	% axes must be named Axes1 in GUI
plotobjs = get(HA,'Children');
datal=0;
for kr=1:length(plotobjs),
   typer=get(plotobjs(kr),'Type');
   if typer=='line',
      datal=datal+1;
	  data{datal}.x=get(plotobjs(kr),'XData');
	  data{datal}.y=get(plotobjs(kr),'YData');
	  data{datal}.z=get(plotobjs(kr),'ZData');
	  if ~isempty(data{datal}.z),
	     twod=0;
	  end
	  data{datal}.c=get(plotobjs(kr),'Color');
	  data{datal}.l=get(plotobjs(kr),'LineStyle');
	  data{datal}.m=get(plotobjs(kr),'Marker');
	  data{datal}.f=get(plotobjs(kr),'MarkerFaceColor');
	  data{datal}.s=get(plotobjs(kr),'MarkerSize');
	  
	  % convert rgb colors to plot commands
	  if data{datal}.c==[1 0 1],
		    color{datal}='m';
      elseif data{datal}.c==[1 1 0],
		    color{datal}='y';
	  elseif data{datal}.c==[0 1 1],
		    color{datal}='c';
	  elseif data{datal}.c==[1 0 0],
		    color{datal}='r';
	  elseif data{datal}.c==[0 1 0],
		    color{datal}='g';
	  elseif data{datal}.c==[0 0 1],
		    color{datal}='b';
	  elseif data{datal}.c==[0 0 0],
		    color{datal}='k';
	  else
		    color{datal}='k';
	  end;
	  
	  % convert plot points to plot commands
	  if strcmp(data{datal}.m,'square')
		    data{datal}.m='s';
	  elseif strcmp(data{datal}.m,'diamond')
		    data{datal}.m='d';
	  elseif strcmp(data{datal}.m,'pentagram')
		    data{datal}.m='p';
	  elseif strcmp(data{datal}.m,'hexagram')
		    data{datal}.m='h';
	  end;
	  
	  % one sigma lines need to be included, make solid
	  if strcmp(data{datal}.l,'-.'),
	     data{datal}.l='-';
	  end;
	  
	  if strcmp(data{datal}.m,'none')
         marker{datal}=strcat(color{datal},data{datal}.l);
	  else
	     marker{datal}=strcat(color{datal},data{datal}.m);
	  end;
	  
	  % only keep the lines, get rid of data points
	  if ~strcmp(data{datal}.l,'-'),
	     datal=datal-1;
	  end;

   elseif typer=='text',    % just has title and axes labels, other text, etc
      if strcmp(get(plotobjs(kr),'Tag'),'sigma')
   	     sigma=get(plotobjs(kr),'String');
		 sigpos=get(plotobjs(kr),'Position');
	  end;
   end;
end;
plottitl = get(get(HA,'Title'),'String');
plotxlab = get(get(HA,'XLabel'),'String');
plotylab = get(get(HA,'YLabel'),'String');
plotxlim = get(HA,'XLim');
plotylim = get(HA,'YLim');
plottype = get(HA,'XScale');

% legend properties
LA = get(findobj('Tag','legend'),'Children');
legl=0;
for kr=1:length(LA),
   typer=get(LA(kr),'Type');
   if typer=='text',
      typer=get(LA(kr),'String');
      if isempty(typer)==0,
         legl=legl+1;
	     leg{legl}.t=get(LA(kr),'String');
	  end;
   end;
end;

% backwards compatibility with older Matlab versions
howm=size(leg{1}.t);
if howm(1)>1,
   legl=howm(1);
   leg{1}.t=flipud(leg{1}.t);
   for kr=length(LA)-1:-1:1,
      leg{kr}.t=leg{1}.t(kr,:);
   end;
end;

% Store into structure PDAT
PDAT.data=data;
PDAT.marker=marker;
PDAT.plottitl=plottitl;
PDAT.plotxlab=plotxlab;
PDAT.plotylab=plotylab;
PDAT.plotxlim=plotxlim;
PDAT.plotylim=plotylim;
PDAT.plottype=plottype;
PDAT.leg=leg;

% Now decide whether it is time to compare or just store results
fid=fopen('SavePlot1.mat','r');
if fid == -1,
   % no files, just save data
   save 'SavePlot1' PDAT;
else
   % 1 already exists, compare with 2
   fclose(fid);
   PDAT2=PDAT;
   load 'SavePlot1';
   PDAT1=PDAT;
   delete 'SavePlot1.mat';
end;

if fid ~= -1,
   newfig=figure('PaperPosition',[1 1 6 4]);
   newax=axes;

   if twod == 1,
      logplot='HN=loglog(';
   elseif twod == 0,
      logplot='HN=plot3(';
   end;
   legplot='legend(';

   for k=datal:-1:1,
      PDAT1.marker{k}=strcat(PDAT1.marker{k},'.');
      if twod == 1,
         logplot=sprintf('%sPDAT1.data{%i}.x,PDAT1.data{%i}.y,PDAT1.marker{%i}',logplot,k,k,k);
      elseif twod == 0,
         logplot=sprintf('%sPDAT1.data{%i}.x,PDAT1.data{%i}.y,PDAT1.data{%i}.z,PDAT1.marker{%i}',logplot,k,k,k,k);
      end;
	  
	  if k>1,
         logplot=sprintf('%s, ',logplot);
      end;
   end
   logplot=sprintf('%s);',logplot);
   eval(logplot);
   hold on;
 
   if twod == 1,
      logplot='HN=loglog(';
   elseif twod == 0,
      logplot='HN=plot3(';
   end;
   
   for k=datal:-1:1,
      if twod == 1,
         logplot=sprintf('%sPDAT2.data{%i}.x,PDAT2.data{%i}.y,PDAT2.marker{%i}',logplot,k,k,k);
      elseif twod == 0,
         logplot=sprintf('%sPDAT2.data{%i}.x,PDAT2.data{%i}.y,PDAT2.data{%i}.z,PDAT2.marker{%i}',logplot,k,k,k,k);
      end;
   
      if k>1,
         logplot=sprintf('%s, ',logplot);
      end;
   end
   logplot=sprintf('%s);',logplot);
   eval(logplot);
   hold off;

   title(strcat(plottitl,' PSDA (-)/IDA (-.)'));
   xlabel(plotxlab);
   ylabel(plotylab);
   set(HN,'MarkerSize',data{1}.s);
   set(newax,'XLim',plotxlim);
   set(newax,'YLim',plotylim);
   set(newax,'XScale',plottype);
   set(newax,'YScale',plottype);
   grid;

   % fix other properties if necessary
   newobjs = get(newax,'Children');
   for k=legl:-1:1,
      legplot=sprintf('%sPDAT1.leg{%i}.t',legplot,k);
      if k>1,
         legplot=sprintf('%s, ',legplot);
      end;
   end
   legplot=sprintf('%s,4);',legplot);
   eval(legplot);

   % now print and clean up
   prompt='Enter file name:';
   titl='Print to File';
   def={'IDAPSDM'};
   answer=inputdlg(prompt,titl,1,def);
   prtv=sprintf('print -depsc2 %s -f2',strcat(answer{1},'.eps'));
   eval(prtv);
   prtv=sprintf('print -dpsc2 %s -f2',strcat(answer{1},'.ps'));
   eval(prtv);

   comptype=computer;
   if strcmp(comptype,'MAC2')==1,
      prtv=sprintf('print -dpict %s -f2',strcat(answer{1},'.pic'));
   else
      prtv=sprintf('print -dtiff %s -f2',strcat(answer{1},'.tif'));
   end;
   eval(prtv);
   close(newfig);

   %set(get(gcf,'Parent'),'ShowHiddenHandles','off');
end;
